@@ -28,23 +28,29 @@ class TradeClass():
             return
     def trade_connect(self,appid,ServiceKey,port):
         self.lock.acquire()
+        data=""
         login_obj = {"Request":"LOGIN","Param":{"SystemName":appid, "ServiceKey":ServiceKey}}
         self.tsocket = self.context.socket(zmq.REQ)
+        self.tsocket.setsockopt(zmq.RCVTIMEO, 2000)
         self.tsocket.connect("tcp://127.0.0.1:%s" % port)
         self.tsocket.send_string(json.dumps(login_obj))
-        message = self.tsocket.recv()
-        message = message[:-1]
-        data = json.loads(message)
-        self.lock.release()
-        if data["Success"] == "OK":
-            self.LoginOK = True
-            self.tsessionKey=data["SessionKey"]
-            threading.Thread(target = self.trade_sub_th,args=(data["SubPort"],"")).start()
-            self.CreatePingPong(data,self.tsocket)
-            return "OK"
-        else:
-            print("交易连线失败")
-            return
+
+        try:
+            message = self.tsocket.recv()
+            message = message[:-1]
+            data = json.loads(message)
+            if data["Success"] == "OK":
+                self.lock.release()
+                self.LoginOK = True
+                self.tsessionKey=data["SessionKey"]
+                threading.Thread(target = self.trade_sub_th,args=(data["SubPort"],"")).start()
+                self.CreatePingPong(data,self.tsocket)
+                data=json.loads("{\"Success\":\"Connected\"}")
+        except:
+            self.tsocket.close()
+            self.lock.release()
+            data = json.loads("{\"Success\":\"ConnectError\"}")
+        return data
 
     #连线登出
     def trade_logout(self):
@@ -78,11 +84,10 @@ class TradeClass():
             self.lock.release()
             if data["Reply"] == "RESTOREREPORT":
                 if len(data["Orders"]) == 0:
-                    break
+                    return datas
                 for ord in data["Orders"]:
                     datas.append(ord)
                     last = ord["QryIndex"]
-            return datas
 
     #查询当日成交回报
     def QryFillReport(self):
@@ -97,11 +102,10 @@ class TradeClass():
             self.lock.release()
             if data["Reply"] == "RESTOREFILLREPORT":
                 if len(data["Orders"]) == 0:
-                    break
+                    return datas
                 for ord in data["Orders"]:
                     datas.append(ord)
                     last = ord["QryIndex"]
-            return datas
     
     #获取委托单信息
     def getorderinfo(self, ordid):
@@ -214,11 +218,11 @@ class TradeClass():
             self.lock.release()
             if data["Reply"] == "POSITIONS":
                 if len(data["Positions"]) == 0:
-                    break
+                    return datas
                 for ord in data["Positions"]:
                     datas.append(ord)
                     last = ord["QryIndex"]
-            return datas
+
     #查询新建组合的委托回报
     def QryOptCombOrder(self, AM, qryIndex=""):
         datas=[]
@@ -232,11 +236,10 @@ class TradeClass():
             self.lock.release()
             if data["Reply"] == "QUERYOPTCOMBORDER":
                 if len(data['Orders']) == 0:
-                    break
+                    return datas
                 for ord in data['Orders']:
                     datas.append(ord)
                     last = ord["QryIndex"]
-            return datas
     #建组合
     def OptComb(self, Param):
         self.lock.acquire()
@@ -260,12 +263,10 @@ class TradeClass():
             self.lock.release()
             if data["Reply"] == "QUERYOPTCOMBPOSITION":
                 if len(data["Positions"]) == 0:
-                    break
+                    return datas
                 for ord in data["Positions"]:
                     datas.append(ord)
                     last = ord["QryIndex"]
-            return datas
-
 
     #查询持仓监控
     def QryPositionTracker(self):
@@ -331,23 +332,29 @@ class QuoteClass():
     #建立行情连线
     def quote_connect(self,appid,ServiceKey, port):
         self.lock.acquire()
+        data=""
         login_obj = {"Request":"LOGIN","Param":{"SystemName":appid, "ServiceKey":ServiceKey}}
         self.qsocket = self.context.socket(zmq.REQ)
+        self.qsocket.setsockopt(zmq.RCVTIMEO, 2000)
         self.qsocket.connect("tcp://127.0.0.1:%s" % port)
         self.qsocket.send_string(json.dumps(login_obj))
-        message = self.qsocket.recv()
-        message = message[:-1]
-        data = json.loads(message)
-        self.lock.release()
-        if data["Success"] == "OK":
-            self.LoginOK = True
-            self.qsessionKey=data["SessionKey"]
-            threading.Thread(target = self.quote_sub_th,args=(data["SubPort"],"")).start()
-            self.CreatePingPong(data,self.qsocket)
-            return "OK"
-        else:
-            print("行情连线失败")
-            return
+
+        try:
+            message = self.qsocket.recv()
+            message = message[:-1]
+            data = json.loads(message)
+            if data["Success"] == "OK":
+                self.lock.release()
+                self.LoginOK = True
+                self.qsessionKey=data["SessionKey"]
+                threading.Thread(target = self.quote_sub_th,args=(data["SubPort"],"")).start()
+                self.CreatePingPong(data,self.qsocket)
+                data=json.loads("{\"Success\":\"Connected\"}")
+        except:
+            self.qsocket.close()
+            self.lock.release()
+            data = json.loads("{\"Success\":\"ConnectError\"}")
+        return data
 
     #连线登出
     def quote_logout(self):
@@ -696,7 +703,7 @@ class QuoteClass():
 
     #最新的K线数据
     def barupdate2(self,bartype,hisdata,realdata):
-        if realdata['DataType']=='REALTIME' and realdata['Quote']["Symbol"]==hisdata[-1]['Symbol'] and  (int(realdata['Quote']['FilledTime'])+80000)<int(realdata['Quote']['CloseTime']):
+        if realdata['DataType']=='REALTIME' and realdata['Quote']["Symbol"]==hisdata[-1]['Symbol'] and  (int(realdata['Quote']['FilledTime'])+80000)<150000:#int(realdata['Quote']['CloseTime']):
             realdata['Quote']["DateTime"]=datetime.strptime(realdata['Quote']['TradeDate']+(" 0" if len(realdata['Quote']['FilledTime'])==5 else " ")+realdata['Quote']['FilledTime'],"%Y%m%d %H%M%S").replace(tzinfo=self.gmt)
             #print(realdata['Quote']["DateTime"])
             if bartype=="DK":
@@ -868,6 +875,8 @@ class QuoteClass():
     #证券：Stock
     def QueryAllInstrumentInfo(self, type,dt=""):
         self.lock.acquire()
+        if dt==time.strftime("%Y%m%d",time.localtime()):
+            dt=""
         obj = {"Request": "QUERYALLINSTRUMENT", "SessionKey": self.qsessionKey, "Type": type, "DateTime": dt}
         self.qsocket.send_string(json.dumps(obj))
         message = self.qsocket.recv()[:-1]
@@ -947,8 +956,18 @@ class TCoreZMQ(TradeClass,QuoteClass):
     def __init__(self,APPID="ZMQ",SKey="8076c9867a372d2a9a814ae710c256e2",quote_port="51864",trade_port="51834",logpath=""):
         TradeClass.__init__(self)
         QuoteClass.__init__(self)
-        self.trade_connect(APPID,SKey,trade_port)
-        self.quote_connect(APPID,SKey,quote_port)
+        for i in range(1000):
+            trade_port=str(int(trade_port)+i)
+            result =self.trade_connect(APPID,SKey,trade_port)
+            ret = result["Success"]
+            if ret != "ConnectError":
+                break
+        for i in range(1000):
+            quote_port=str(int(quote_port)+i)
+            result =self.quote_connect(APPID,SKey,quote_port)
+            ret = result["Success"]
+            if ret != "ConnectError":
+                break
         self.logger = logging.getLogger(__name__)
         self.logger.setLevel(level = logging.INFO)
         if logpath:
